This folder is used to auto-generate the orchestrator configuration file (aka TaskGraph) based on the user's natural language description and domain knowledge. The user can provide the description of the task that they want Arklex to achieve and the domain knowledge that Arklex built upon. For example, the resources that orchestrator have access to, e.g website content, availble APIs, database, etc. Then the generator will generate the json configuration file for the user. The user can then modify the configuration file to fit their needs. The orchestrator will load the configuration file and reconstruct the TaskGraph to complete the task.
